From b77e711482cd31392725e31bed8bde724d437058 Mon Sep 17 00:00:00 2001
From: Chris Lamb <lamby@debian.org>
Date: Fri, 24 Jul 2009 19:30:46 +0200
Subject: [PATCH 1/7] Add "usb-partition" argument to list-devices for detecting partitions on USB drives. Patch originally by Tormod Volden <debian.tormod@gmail.com>.

---
 packages/debian-installer-utils/debian/changelog |    5 +++++
 packages/debian-installer-utils/list-devices     |   17 +++++++++++++++--
 2 files changed, 20 insertions(+), 2 deletions(-)

diff --git a/packages/debian-installer-utils/debian/changelog b/packages/debian-installer-utils/debian/changelog
index 2979010..213405f 100644
--- a/packages/debian-installer-utils/debian/changelog
+++ b/packages/debian-installer-utils/debian/changelog
@@ -1,11 +1,16 @@
 debian-installer-utils (1.72) UNRELEASED; urgency=low
 
+  [ Colin Watson ]
   * Upgrade to debhelper v7.
 
   [ Aurelien Jarno ]
   * Also ship other terminfo on GNU/kFreeBSD, they are also used in some
     cases (e.g. installation through ssh).
 
+  [ Chris Lamb ]
+  * Add "usb-partition" argument to list-devices for detecting partitions on
+    USB drives. Patch originally by Tormod Volden <debian.tormod@gmail.com>.
+
  -- Colin Watson <cjwatson@debian.org>  Thu, 13 Aug 2009 14:52:50 +0100
 
 debian-installer-utils (1.71) unstable; urgency=low
diff --git a/packages/debian-installer-utils/list-devices b/packages/debian-installer-utils/list-devices
index b748be9..2a95b71 100755
--- a/packages/debian-installer-utils/list-devices
+++ b/packages/debian-installer-utils/list-devices
@@ -6,9 +6,9 @@ case $TYPE in
 	logger -t list-devices "deprecated parameter maybe-floppy"
 	TYPE=floppy
 	;;
-    cd|disk|partition|floppy|maybe-usb-floppy) ;;
+    cd|disk|partition|floppy|maybe-usb-floppy|usb-partition) ;;
     *)
-	echo "Usage: $0 cd|disk|partition|floppy|maybe-usb-floppy" >&2
+	echo "Usage: $0 cd|disk|partition|floppy|maybe-usb-floppy|usb-partition" >&2
 	exit 2
 	;;
 esac
@@ -40,6 +40,12 @@ case $TYPE in
 	# Also allow misdetected USB devices
 	scan_partition=:
 	;;
+    usb-partition)
+	for x in /sys/block/*/*; do
+		[ -d "$x" ] || continue
+		syspaths="${syspaths:+$syspaths }$x"
+	done
+	;;
     *)
 	for x in /sys/block/*; do
 		[ -d "$x" ] || continue
@@ -85,6 +91,13 @@ for x in $syspaths; do
 			match=:
 		fi
 	fi
+	# Disk partitions, but only on USB drives
+	if ! $match && [ "$TYPE" = usb-partition ]; then
+		if device_info env "$devpath" | grep -q '^ID_BUS=usb' && \
+		   device_info env "$devpath" | grep -q '^ID_TYPE=disk'; then
+			match=:
+		fi
+	fi
 	if $match; then
 		if ! name="$(device_info name "$devpath")"; then
 			name="$(printf %s "${devpath##*/}" | \
-- 
1.6.3.3

